@@ -1,3 +1,3 @@
 from .ilovepdf import Compress, ILovePDF, Task
 from .main import DEFAULT_SUFFIX, main
-from .utils import sizeof_fmt
+from .utils import si_fmt
