@@ -61,7 +61,7 @@ def si_fmt(
     return f"{val:{fmt_spec}}{sep}{scale}"
 
 
-def load_dotenv(filepath: str = f"{ROOT}/.env") -> None:
+def load_dotenv(filepath: str = os.path.join(f"{ROOT}", ".env")) -> None:
     """Parse environment variables in .env into os.environ.
 
     Args:
@@ -134,7 +134,7 @@ def del_or_keep_compressed(
         compressed_files = sorted(archive.namelist())
         archive.extractall()
 
-    trash_path = f"{expanduser('~')}/.Trash"
+    trash_path = f"{expanduser('~')}/.Trash"  # macOS only, no need for os.path.join()
 
     for idx, (orig_path, compr_path) in enumerate(zip(pdfs, compressed_files), 1):
 
@@ -145,7 +145,7 @@ def del_or_keep_compressed(
         counter = f"\n{idx}: " if n_files > 1 else ""
 
         if diff / orig_size > min_size_reduction / 100:
-            pretty_path = relpath(orig_path, expanduser("~"))
+            pretty_path = relpath(orig_path)
             print(
                 f"{counter}'{pretty_path}' is now {si_fmt(compressed_size)}B, before "
                 f"{si_fmt(orig_size)}B ({si_fmt(diff)}B = {diff/orig_size:.1%} smaller)"
@@ -164,7 +164,9 @@ def del_or_keep_compressed(
                 else:
                     print("Old file deleted.")
 
-                os.rename(compr_path, orig_path)
+                # better then os.rename() on Windows which errors if destination file
+                # path already exists
+                os.replace(compr_path, orig_path)
 
             elif suffix:
                 new_path = make_uniq_filename(orig_path, suffix)
